/*
 * Copyright 2015 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.gradle.internal.operations;

import org.jspecify.annotations.Nullable;

public class DefaultBuildOperationRef implements BuildOperationRef {

    private final @Nullable OperationIdentifier id;
    private final @Nullable OperationIdentifier parentId;

    public DefaultBuildOperationRef(@Nullable OperationIdentifier id, @Nullable OperationIdentifier parentId) {
        this.id = id;
        this.parentId = parentId;
    }

    @Override
    public @Nullable OperationIdentifier getId() {
        return id;
    }

    @Override
    public @Nullable OperationIdentifier getParentId() {
        return parentId;
    }

}
